@@ -1,6 +1,6 @@
 import logging
 from io import IOBase
-from typing import Generator
+from typing import Generator, Any
 
 from minio import Minio
 from minio.datatypes import Object
@@ -88,7 +88,7 @@ def list_objects(bucket_name: str, prefix: str, recursive: bool = True) -> Gener
     yield from s3_client.list_objects(bucket_name, prefix=prefix, recursive=recursive)
 
 
-def get_objects(bucket_name: str, path: str, recursive: bool = True) -> Generator[tuple[str, bytes], None, None]:
+def get_objects(bucket_name: str, path: str, recursive: bool = True) -> Generator[tuple[str, Any, bytes], None, None]:
     for obj in list_objects(bucket_name, path, recursive):
         object_name = obj.object_name
 
@@ -97,4 +97,4 @@ def get_objects(bucket_name: str, path: str, recursive: bool = True) -> Generato
         else:
             data = b''
 
-        yield object_name, data
+        yield object_name, obj.last_modified, data
